==============
 Installation
==============

Install the extension with one of the following commands::

    $ easy_install sigal

or preferably if you have pip installed::

    $ pip install sigal

To install the development version, see the :doc:`contribute`.

Also, note that Sigal depends on `Pillow
<https://github.com/python-pillow/Pillow>`_, which needs specific libraries when
building from sources. See their `Installation documentation
<https://pillow.readthedocs.io/en/stable/installation.html>`_ for more details.

Dependencies
~~~~~~~~~~~~

- Blinker
- Click
- Jinja2
- Pilkit
- Pillow
- Python Markdown

Packages
~~~~~~~~

Some packages are available for Linux distributions:

- `Archlinux <https://aur.archlinux.org/packages/sigal/>`_
- `Gentoo <https://packages.gentoo.org/packages/media-gfx/sigal>`_
- `OpenSuse
  <https://build.opensuse.org/package/show/openSUSE:Factory/python-sigal>`_
- `NixOS <https://nixos.org/nixos/packages.html#sigal>`_
